@@ -1,13 +1,12 @@
 package Bot::Cobalt::Plugin::Extras::TempConv;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 ## RECEIVES AND EATS:
 ##  _public_cmd_tempconv  ( !tempconv )
 ##  _public_cmd_temp      ( !temp )
 
 use 5.10.1;
-use strict;
-use warnings;
+use strictures 1;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 use Bot::Cobalt::Utils qw/ color /;
