@@ -1,18 +1,14 @@
 package Bot::Cobalt::Plugin::PluginMgr;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 ## handles and eats: !plugin
 
-use 5.10.1;
-use strict;
-use warnings;
-
-use Object::Pluggable::Constants qw/ :ALL /;
+use 5.12.1;
+use strictures 1;
 
 use Bot::Cobalt;
-
+use Bot::Cobalt::Common;
 use Bot::Cobalt::Conf;
-
 use Bot::Cobalt::Core::Loader;
 
 use Scalar::Util qw/blessed/;
@@ -44,15 +40,15 @@ sub Cobalt_unregister {
 sub Bot_public_cmd_plugin {
   my ($self, $core) = splice @_, 0, 2;
   my $msg = ${$_[0]};
-  my $context = $msg->context;
 
+  my $context = $msg->context;
   my $chan = $msg->channel;
   my $nick = $msg->src_nick;
   
   my $pcfg = core()->get_plugin_cfg( $self );
 
   ## default to superuser-only:
-  my $required_lev = $pcfg->{PluginOpts}->{LevelRequired} // 9999;
+  my $required_lev = $pcfg->{LevelRequired} // 9999;
 
   my $resp;
 
@@ -83,186 +79,11 @@ sub Bot_public_cmd_plugin {
   return PLUGIN_EAT_ALL
 }
 
-sub _unload {
-  my ($self, $alias) = @_;
-
-  my $resp;
-
-  my $plug_obj = core()->plugin_get($alias);
-  my $plugisa = ref $plug_obj || return "_unload broken? no PLUGISA";
-
-  if (! $alias) {
-    return "Bad syntax; no plugin alias specified";
-
-  } elsif (! $plug_obj ) {
-    return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
-      plugin => $alias,
-      err => 'No such plugin found, is it loaded?' 
-    );
-
-  } elsif (! Bot::Cobalt::Core::Loader->is_reloadable($plug_obj) ) {
-    return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
-      plugin => $alias,
-      err => "Plugin $alias is marked as non-reloadable",
-   );
-
-  }
-
-  logger->info("Attempting to unload $alias ($plugisa) per request");
-
-  if ( core()->plugin_del($alias) ) {
-    delete core()->PluginObjects->{$plug_obj};
-
-    Bot::Cobalt::Core::Loader->unload($plugisa);
-
-    ## also cleanup our config if there is one:
-    delete core()->cfg->{plugin_cf}->{$alias};
-
-    ## and timers:
-    core()->timer_del_alias($alias);
-      
-    return core->rpl( q{RPL_PLUGIN_UNLOAD}, 
-        plugin => $alias
-    );
-  } else {
-    return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
-      plugin => $alias, 
-      err => 'Unknown failure'
-    );
-  }
-
-  return
-}
-
-sub _load_module {
-  ## _load_module( 'Auth', 'Bot::Cobalt::Plugin::Auth' ) f.ex
-  ## returns a response string for irc
-  my ($self, $alias, $module) = @_;
-
-  my ($err, $obj);
-  try {
-    $obj = Bot::Cobalt::Core::Loader->load($module);
-  } catch {
-    $err = $_
-  };
-
-  if ($err) {
-    ## 'require' failed
-    logger->warn("Plugin load failure; $err");
-    
-    Bot::Cobalt::Core::Loader->unload($module);
-
-    return core->rpl( q{RPL_PLUGIN_ERR},
-      plugin => $alias,
-      err => "Module $module cannot be found/loaded: $err",
-    );
-  }
-
-  ## store plugin objects:
-  core()->PluginObjects->{$obj} = $alias;
-
-  ## plugin_add returns # of plugins in pipeline on success:
-  if (my $loaded = core()->plugin_add( $alias, $obj ) ) {
-    unless ( Bot::Cobalt::Core::Loader->is_reloadable($obj) ) {
-      core()->State->{NonReloadable}->{$alias} = 1;
-      logger->debug("$alias flagged non-reloadable");
-    }
-      
-    my $modversion = $obj->can('VERSION') ? $obj->VERSION : 1 ;
-      
-    return core->rpl( q{RPL_PLUGIN_LOAD},
-      plugin  => $alias,
-      module  => $module,
-      version => $modversion,
-    );
-  } else {
-    ## Couldn't plugin_add
-    logger->error("plugin_add failure for $alias");
-
-    ## run cleanup  
-    Bot::Cobalt::Core::Loader->unload($module);
-
-    delete core()->PluginObjects->{$obj};
-
-    return core->rpl( q{RPL_PLUGIN_ERR},
-      plugin => $alias,
-      err => "Unknown plugin_add failure",
-    );
-  }
-
-}
-
-sub _load {
-  my ($self, $alias, $module, $reload) = @_;
-
-  return "Bad syntax; usage: load <alias> [module]"
-    unless $alias;
-
-  ## check list to see if alias is already loaded
-  my $pluglist = core()->plugin_list;
-
-  return "Plugin already loaded: $alias"
-    if $alias ~~ [ keys %$pluglist ] ;
-
-  my $pluginscf = core()->cfg->{plugins};  # plugins.conf
-
-  if ($module) {
-    ## user (or 'reload') specified a module for this alias
-    ## it could still have conf opts specified:
-    $self->_load_conf($alias, $module, $pluginscf);
-    return $self->_load_module($alias, $module);
-
-  } else {
-
-    unless (exists $pluginscf->{$alias}
-            && ref $pluginscf->{$alias} eq 'HASH') {
-      return core->rpl( q{RPL_PLUGIN_ERR},
-        {
-          plugin => $alias,
-          err => "No '${alias}' plugin found in plugins.conf",
-        }
-      );
-    }
-
-    my $pkgname = $pluginscf->{$alias}->{Module};
-    unless ($pkgname) {
-      return core->rpl( q{RPL_PLUGIN_ERR},
-        {
-          plugin => $alias,
-          err => "No Module specified in plugins.conf for plugin '${alias}'",
-        }
-      );
-    }
-
-    ## read conf into core:
-    $self->_load_conf($alias, $pkgname, $pluginscf);
-
-    ## load the plugin:
-    return $self->_load_module($alias, $pkgname);
-  }
-
-}
-
-sub _load_conf {
-  my ($self, $alias, $pkgname, $pluginscf) = @_;
-
-  $pluginscf = $self->_read_core_plugins_conf unless $pluginscf;
-
-  ## (re)load this plugin's configuration before loadtime
-  my $cconf = Bot::Cobalt::Conf->new(
-    etc => core()->cfg->{path}
-  );
-
-  ## use our current plugins.conf (not a rehash)
-  my $thisplugcf = $cconf->_read_plugin_conf($alias, $pluginscf);
-  $thisplugcf = {} unless ref $thisplugcf;
-
-  core()->cfg->{plugin_cf}->{$alias} = $thisplugcf;
-}
-
-
 sub _cmd_plug_load {
   my ($self, $msg) = @_;
+
+  ## !load Alias
+  ## !load Alias Module
   
   my ($alias, $module) = @{ $msg->message_array }[1,2];
   
@@ -271,6 +92,8 @@ sub _cmd_plug_load {
 
 sub _cmd_plug_unload {
   my ($self, $msg) = @_;
+
+  ## !unload Alias
   
   my $alias = $msg->message_array->[1];
 
@@ -345,6 +168,139 @@ sub _cmd_plug_reload {
   return $self->_load($alias, $pkgisa);
 }
 
+sub _unload {
+  my ($self, $alias) = @_;
+
+  my $resp;
+
+  my $plug_obj = core()->plugin_get($alias);
+  my $plugisa = ref $plug_obj || return "_unload broken? no PLUGISA";
+
+  return "Bad syntax; no plugin alias specified"
+    unless defined $alias;
+
+  return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
+      plugin => $alias,
+      err => 'No such plugin found, is it loaded?' 
+  ) unless $plug_obj;
+
+  return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
+      plugin => $alias,
+      err => "Plugin $alias is marked as non-reloadable",
+ ) unless Bot::Cobalt::Core::Loader->is_reloadable($plug_obj);
+
+  logger->info("Attempting to unload $alias ($plugisa) per request");
+
+  if ( core()->plugin_del($alias) ) {
+    delete core()->PluginObjects->{$plug_obj};
+
+    Bot::Cobalt::Core::Loader->unload($plugisa);
+
+    ## and timers:
+    core()->timer_del_alias($alias);
+      
+    return core->rpl( q{RPL_PLUGIN_UNLOAD}, 
+        plugin => $alias
+    )
+  } else {
+    return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
+      plugin => $alias, 
+      err => 'Unknown core->plugin_del failure'
+    )
+  }
+
+  return
+}
+
+sub _load {
+  my ($self, $alias, $module) = @_;
+  
+  ## Called for !load / !reload
+  ## Return string for IRC
+  
+  return "Bad syntax; usage: load <alias> [module]"
+    unless defined $alias;
+
+  return "Plugin already loaded: $alias"
+    if $alias ~~ [ keys %{ core->plugin_list } ] ;
+
+  return $self->_load_module($alias, $module)
+    if defined $module;
+
+  my $plugin_cfg;
+  ## No module specified; do we know this alias?
+  unless ( $plugin_cfg = core()->cfg->plugins->plugin($alias) ) {
+    return core->rpl( q{RPL_PLUGIN_ERR},
+      plugin => $alias,
+      err => "Plugin '$alias' not found in plugins conf",
+    )
+  }
+  
+  return $self->_load_module(
+    $alias,
+    $plugin_cfg->module
+  )
+}
+
+sub _load_module {
+  ## _load_module( 'Auth', 'Bot::Cobalt::Plugin::Auth' ) f.ex
+  ## load to Core
+  ## returns a response string for irc
+  my ($self, $alias, $module) = @_;
+
+  my ($err, $obj);
+  try {
+    $obj = Bot::Cobalt::Core::Loader->load($module);
+  } catch {
+    $err = $_
+  };
+
+  if ($err) {
+    logger->warn("Plugin load failure; $err");
+    
+    Bot::Cobalt::Core::Loader->unload($module);
+
+    return core->rpl( q{RPL_PLUGIN_ERR},
+      plugin => $alias,
+      err => "Module $module cannot be found/loaded: $err",
+    );
+  }
+
+  ## store plugin objects:
+  core()->PluginObjects->{$obj} = $alias;
+
+  ## plugin_add returns # of plugins in pipeline on success:
+  if (my $loaded = core()->plugin_add( $alias, $obj ) ) {
+    unless ( Bot::Cobalt::Core::Loader->is_reloadable($obj) ) {
+      core()->State->{NonReloadable}->{$alias} = 1;
+      logger->debug("$alias flagged non-reloadable");
+    }
+      
+    my $modversion = $obj->can('VERSION') ? $obj->VERSION : 1 ;
+      
+    return core->rpl( q{RPL_PLUGIN_LOAD},
+      plugin  => $alias,
+      module  => $module,
+      version => $modversion,
+    );
+  } else {
+    ## Couldn't plugin_add
+    logger->error("plugin_add failure for $alias");
+
+    ## run cleanup  
+    Bot::Cobalt::Core::Loader->unload($module);
+
+    delete core()->PluginObjects->{$obj};
+
+    return core->rpl( q{RPL_PLUGIN_ERR},
+      plugin => $alias,
+      err => "Unknown plugin_add failure",
+    );
+  }
+
+}
+
+
 1;
 __END__
 
@@ -400,8 +356,9 @@ Otherwise, a module must be specified:
 
   <JoeUser> !plugin load Shorten Bot::Cobalt::Plugin::Extras::Shorten
 
-If the module's alias has a Config or Opts specified, they will 
-also be loaded.
+As of Bot-Cobalt-0.013, '!load' no longer rehashes plugin configuration 
+values; use '!rehash plugins' from L<Bot::Cobalt::Plugin::Rehash> 
+instead.
 
 =head2 unload
 
@@ -411,9 +368,7 @@ The only argument is the plugin's alias.
 
 =head2 reload
 
-Unload and re-load the specified plugin, rehashing any applicable 
-configuration.
-
+Unload and re-load the specified plugin.
 
 =head1 AUTHOR
 
