@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Seen;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use 5.10.1;
 
@@ -51,8 +51,7 @@ sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
     
   my $pcfg = $core->get_plugin_cfg($self);
-  my $seendb_path = $pcfg->{PluginOpts}->{SeenDB}
-                    || "seen.db" ;
+  my $seendb_path = $pcfg->{SeenDB} || "seen.db" ;
   
   $seendb_path = File::Spec->catfile( $core->var, $seendb_path );
   
@@ -155,6 +154,7 @@ sub Bot_seendb_update {
   $core->timer_set( 3,
     { Event => 'seendb_update' }
   );  
+
   return PLUGIN_EAT_ALL
 }
 
